Module mount

Module mount 

Linux >=5.2 file system mount API.

This crate provides access to the kernel’s new mount API.

Modules

fs
File system instances.
ns
Mount namespace related code.
superblock
Superblock instances creates from file systems via Fs::create.
sys
Constants for the fsmount API.

Structs

Fs
Represents a handle to a file system.
FsMount
Mount flags for Superblock::mount.
FsOpen
Flags for Fs::open.
FsPick
Flags for Superblock::fspick.
ListMounts
An iterator over the mount IDs inside a mount namespace.
Mount
Handle to a mount point. Used to move or bind mount points or change their attributes.
MountAttr
Mount attributes for Superblock::mount or Mount::setattr.
MountId
A unique mount ID as used in statmount(2), listmount(2) or statx(2).
MountNsId
The mount namespace ID.
MountSetAttr
The struct mount_attr
MoveMount
Flags for handling the “from” and “to” parts of a move_mount operation.
OpenTree
Flags for the open_tree function.
ReusedMountId
Reused mount IDs are the ones used in /proc/*/mountinfo.
StatMount
A buffer used for and result of a statmount(2) call.
StatMountBuilder
A builder for a statmount(2) call.
Superblock
Handle to a file system superblock.

Functions

list
Get an iterator over the mounts in the current namespace starting at the root.
umount
Wrapper for the umount2(2) system call.